@@ -59,8 +59,9 @@
 #' @param distribution A \code{character} string. The distribution function of the response.
 #'        Must be "AUTO", "bernoulli", "multinomial", "poisson", "gamma", "tweedie",
 #'        "laplace", "huber", "quantile" or "gaussian"
-#' @param quantile_alpha Quantile (only for Quantile regression, must be between 0 and 1)
-#' @param tweedie_power Tweedie power (only for Tweedie distribution, must be between 1 and 2).
+#' @param quantile_alpha Desired quantile for Quantile regression, must be between 0 and 1.
+#' @param huber_alpha Desired quantile for Huber/M-regression (threshold between quadratic and linear loss, must be between 0 and 1).
+#' @param tweedie_power Tweedie power for Tweedie regression, must be between 1 and 2.
 #' @param score_interval Shortest time interval (in secs) between model scoring.
 #' @param score_training_samples Number of training set samples for scoring (0 for all).
 #' @param score_validation_samples Number of validation set samples for scoring (0 for all).
@@ -75,7 +76,7 @@
 #'        (by stopping_tolerance) for k=stopping_rounds scoring events.
 #'        Can only trigger after at least 2k scoring events. Use 0 to disable.
 #' @param stopping_metric Metric to use for convergence checking, only for _stopping_rounds > 0
-#'        Can be one of "AUTO", "deviance", "logloss", "MSE", "AUC", "r2", "misclassification", or "mean_per_class_error".
+#'        Can be one of "AUTO", "deviance", "logloss", "MSE", "AUC", "misclassification", or "mean_per_class_error".
 #' @param stopping_tolerance Relative tolerance for metric-based stopping criterion (if relative
 #'        improvement is not at least this much, stop).
 #' @param max_runtime_secs Maximum allowed runtime in seconds for model training. Use 0 to disable.
@@ -111,6 +112,8 @@
 #' @param sparsity_beta Sparsity regularization (Experimental).
 #' @param max_categorical_features Max. number of categorical features, enforced via hashing
 #'        Experimental).
+#' @param categorical_encoding Encoding scheme for categorical features, must be "AUTO", "Enum", 
+#         "OneHotInternal", "OneHotExplicit", "Binary" or "Eigen"
 #' @param reproducible Force reproducibility on small data (requires setting the \code{seed} argument and this will be slow - only uses 1 thread).
 #' @param export_weights_and_biases Whether to export Neural Network weights and biases to H2O.
 #'        Frames"
@@ -175,6 +178,7 @@ h2o.deeplearning <- function(x, y, training_frame,
                              distribution = c("AUTO","gaussian", "bernoulli", "multinomial", "poisson", "gamma", "tweedie", "laplace", "huber", "quantile"),
                              quantile_alpha = 0.5,
                              tweedie_power = 1.5,
+                             huber_alpha,
                              score_interval = 5,
                              score_training_samples,
                              score_validation_samples,
@@ -206,6 +210,7 @@ h2o.deeplearning <- function(x, y, training_frame,
                              average_activation,
                              sparsity_beta,
                              max_categorical_features,
+                             categorical_encoding = c("AUTO","Enum","OneHotInternal","OneHotExplicit","Binary","Eigen"),
                              reproducible=FALSE,
                              export_weights_and_biases=FALSE,
                              offset_column = NULL,
@@ -323,6 +328,8 @@ h2o.deeplearning <- function(x, y, training_frame,
     parms$quantile_alpha <- quantile_alpha
   if (!missing(tweedie_power))
     parms$tweedie_power <- tweedie_power
+  if (!missing(huber_alpha))
+    parms$huber_alpha <- huber_alpha
   if(!missing(score_interval))
     parms$score_interval <- score_interval
   if(!missing(score_training_samples))
@@ -379,6 +386,8 @@ h2o.deeplearning <- function(x, y, training_frame,
     parms$sparsity_beta <- sparsity_beta
   if(!missing(max_categorical_features))
     parms$max_categorical_features <- max_categorical_features
+  if(!missing(categorical_encoding))
+    parms$categorical_encoding <- categorical_encoding
   if(!missing(reproducible))
     parms$reproducible <- reproducible
   if(!missing(export_weights_and_biases))
