@@ -11,12 +11,17 @@
 #' Imports files into an H2O cloud. The default behavior is to pass-through to the parse phase
 #' automatically.
 #'
-#' Other than \code{h2o.uploadFile}, if the given path is relative, then it will be relative to the
-#' start location of the H2O instance. Additionally, the file must be on the same machine as the H2O
-#' cloud. In the case of \code{h2o.uploadFile}, a relative path will resolve relative to the working
-#' directory of the current R session.
+#' \code{h2o.importFile} is a parallelized reader and pulls information from the server from a location specified
+#' by the client. The path is a server-side path. This is a fast, scalable, highly optimized way to read data. H2O
+#' pulls the data from a data store and initiates the data transfer as a read operation.
 #'
-#' Import an entire directory of files. If the given path is relative, then it
+#' Unlike the import function, which is a parallelized reader, \code{h2o.uploadFile} is a push from
+#' the client to the server. The specified path must be a client-side path. This is not scalable and is only
+#' intended for smaller data sizes. The client pushes the data from a local filesystem (for example,
+#' on your machine where R is running) to H2O. For big-data operations, you don't want the data
+#' stored on or flowing through the client.
+#'
+#' \code{h2o.importFolder} imports an entire directory of files. If the given path is relative, then it
 #' will be relative to the start location of the H2O instance. The default
 #' behavior is to pass-through to the parse phase automatically.
 #'
@@ -52,12 +57,23 @@
 #' \donttest{
 #' h2o.init(ip = "localhost", port = 54321, startH2O = TRUE)
 #' prosPath = system.file("extdata", "prostate.csv", package = "h2o")
-#' prostate.hex = h2o.uploadFile(path = prosPath, destination_frame = "prostate.hex")
+#' prostate.hex = h2o.importFile(path = prosPath, destination_frame = "prostate.hex")
 #' class(prostate.hex)
 #' summary(prostate.hex)
 #' }
+
+
 #' @name h2o.importFile
 #' @export
+h2o.importFile <- function(path, destination_frame = "", parse = TRUE, header=NA, sep = "", col.names=NULL,
+                           col.types=NULL, na.strings=NULL) {
+  h2o.importFolder(path, pattern = "", destination_frame=destination_frame, parse, header, sep, col.names, col.types,
+                   na.strings=na.strings)
+}
+
+
+#' @rdname h2o.importFile
+#' @export
 h2o.importFolder <- function(path, pattern = "", destination_frame = "", parse = TRUE, header = NA, sep = "",
                              col.names = NULL, col.types=NULL, na.strings=NULL) {
   if(!is.character(path) || is.na(path) || !nzchar(path)) stop("`path` must be a non-empty character string")
@@ -87,9 +103,14 @@ h2o.importFolder <- function(path, pattern = "", destination_frame = "", parse =
   # Return only the files that successfully imported
   if(length(res$files) <= 0L) stop("all files failed to import")
   if(parse) {
-    srcKey <- res$destination_frames
-    return( h2o.parseRaw(data=.newH2OFrame(op="ImportFolder",id=srcKey,-1,-1), destination_frame=destination_frame,
-                         header=header, sep=sep, col.names=col.names, col.types=col.types, na.strings=na.strings) )
+    if(pattern=="") {srcKey <- res$destination_frames
+    } else {srcKey  <- res$destination_frames[grepl(pattern,res$destination_frames)]}
+    if(length(srcKey)>0){
+      return( h2o.parseRaw(data=.newH2OFrame(op="ImportFolder",id=srcKey,-1,-1), destination_frame=destination_frame,
+                           header=header, sep=sep, col.names=col.names, col.types=col.types, na.strings=na.strings) )
+    }else{
+      stop("all files failed to import - No file has this `pattern` ")
+    }
   }
   myData <- lapply(res$destination_frames, function(x) .newH2OFrame( op="ImportFolder", id=x,-1,-1))  # do not gc, H2O handles these nfs:// vecs
   if(length(res$destination_frames) == 1L)
@@ -99,14 +120,6 @@ h2o.importFolder <- function(path, pattern = "", destination_frame = "", parse =
 }
 
 
-#' @export
-h2o.importFile <- function(path, destination_frame = "", parse = TRUE, header=NA, sep = "", col.names=NULL,
-                           col.types=NULL, na.strings=NULL) {
-  h2o.importFolder(path, pattern = "", destination_frame=destination_frame, parse, header, sep, col.names, col.types,
-                   na.strings=na.strings)
-}
-
-
 #' @rdname h2o.importFile
 #' @export
 h2o.importURL <- function(path, destination_frame = "", parse = TRUE, header = NA, sep = "", col.names = NULL, na.strings=NULL) {
